'use strict';

var _glob = require('glob');

var _glob2 = _interopRequireDefault(_glob);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _lodash = require('lodash');

var _fileOptions = require('../schema/injectors/file-options');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

module.exports = function (options) {
  return function (file) {
    var valid = (0, _fileOptions.validateOptions)(options);
    if (!valid) throw new Error(schema.errorsText());

    options = (0, _lodash.defaults)(options || {}, _fileOptions.defaultOptions);

    var _options = options,
        patterns = _options.patterns,
        baseDir = _options.baseDir,
        verbose = _options.verbose;


    if (verbose) {
      console.log('fileInjector: options are ' + JSON.stringify(options, null, 2));
    }

    var jsonFile = patterns.map(function (pattern) {
      var p = file ? pattern.replace('{file}', _path2.default.basename(file)) : pattern;
      if (verbose) {
        console.log('fileInjector: search for files with pattern ' + p);
      }
      return _glob2.default.sync(p, {
        cwd: baseDir
      });
    }).map(function (jsonFiles) {
      if (verbose) {
        console.log('fileInjector: json files are ' + jsonFiles.join(', '));
      }
      return jsonFiles.map(function (f) {
        return require(_path2.default.resolve(baseDir, f));
      }).reduce(function (a, b) {
        return Object.assign(a, b);
      }, {});
    }).reduce(function (a, b) {
      return Object.assign(a, b);
    }, {});

    if (verbose) {
      console.log('fileInjector: result is ' + JSON.stringify(jsonFile, null, 2));
    }

    return jsonFile;
  };
};